/*
 * Copyright 2008-2012 Amazon Technologies, Inc. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at:
 * 
 *    http://aws.amazon.com/apache2.0
 *
 * This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES 
 * OR CONDITIONS OF ANY KIND, either express or implied. See the 
 * License for the specific language governing permissions and 
 * limitations under the License. 
 */

package com.amazonaws.eclipse.ec2;

/**
 * Simple data object describing the details of an attempt to execute a shell
 * command, including error code, stdout, stderr, etc.
 */
public class ShellCommandResults {
    /** The output generated by the shell command */
    public final String output;
    
    /** The error output generated by the shell command */
    public final String errorOutput;
    
    /** The exit code of the shell command */
    public final int exitCode;

    /**
     * Constructs a new ShellCommandResults object.
     * 
     * @param output
     *            The contents of STDOUT.
     * @param errorOutput
     *            The contents of STDERR.
     * @param exitCode
     *            The exit code of the shell command.
     */
    public ShellCommandResults(String output, String errorOutput, int exitCode) {
        this.output = output;
        this.errorOutput = errorOutput;
        this.exitCode = exitCode;
    }

}
